@@ -1,23 +1,23 @@
 var searchData=
 [
-  ['uattributes_0',['uAttributes',['../a01526.html#a257bd1afa651e50183767f438112e30d',1,'_oslVolumeInfo::uAttributes()'],['../a01522.html#a40f4d1d56f02d357a7cd263defaa06a1',1,'_oslFileStatus::uAttributes()']]],
-  ['ufilesize_1',['uFileSize',['../a01522.html#a75ceaf2d09b3dba8ab6ebbcc07d2f721',1,'_oslFileStatus']]],
-  ['ufreespace_2',['uFreeSpace',['../a01526.html#af0cde1f869fb488ada3e2b248a7035d3',1,'_oslVolumeInfo']]],
+  ['uattributes_0',['uattributes',['../a00770.html#a257bd1afa651e50183767f438112e30d',1,'_oslVolumeInfo::uAttributes'],['../a00766.html#a40f4d1d56f02d357a7cd263defaa06a1',1,'_oslFileStatus::uAttributes']]],
+  ['ufilesize_1',['uFileSize',['../a00766.html#a75ceaf2d09b3dba8ab6ebbcc07d2f721',1,'_oslFileStatus']]],
+  ['ufreespace_2',['uFreeSpace',['../a00770.html#af0cde1f869fb488ada3e2b248a7035d3',1,'_oslVolumeInfo']]],
   ['uik_2eh_3',['uik.h',['../a00257.html',1,'']]],
-  ['umaxnamelength_4',['uMaxNameLength',['../a01526.html#a11f139af77f919366cb6fc791eb863c7',1,'_oslVolumeInfo']]],
-  ['umaxpathlength_5',['uMaxPathLength',['../a01526.html#a18ee684455fa2a6505d43ec781704b7b',1,'_oslVolumeInfo']]],
-  ['unacquired_6',['unacquired',['../a01794.html#a95e4d738f91a83ab47b7d21330207534',1,'rtl::OUString']]],
-  ['unknown_7',['Unknown',['../a01542.html#a17884cd168469537e71c44a0813c8d2ba748257fb60af245eba6bd3252d29e051',1,'osl::FileStatus']]],
-  ['unload_8',['unload',['../a01566.html#a1f9acce10ccae323f19fc262e39e8bd6',1,'osl::Module']]],
+  ['umaxnamelength_4',['uMaxNameLength',['../a00770.html#a11f139af77f919366cb6fc791eb863c7',1,'_oslVolumeInfo']]],
+  ['umaxpathlength_5',['uMaxPathLength',['../a00770.html#a18ee684455fa2a6505d43ec781704b7b',1,'_oslVolumeInfo']]],
+  ['unacquired_6',['unacquired',['../a00754.html#a95e4d738f91a83ab47b7d21330207534',1,'rtl::OUString']]],
+  ['unknown_7',['Unknown',['../a00786.html#a17884cd168469537e71c44a0813c8d2ba748257fb60af245eba6bd3252d29e051',1,'osl::FileStatus']]],
+  ['unload_8',['unload',['../a00810.html#a1f9acce10ccae323f19fc262e39e8bd6',1,'osl::Module']]],
   ['unload_2eh_9',['unload.h',['../a00140.html',1,'']]],
   ['uno_5facquirefunc_10',['uno_AcquireFunc',['../a00275.html#ae005c271af398d0842fdeea3a95315a1',1,'data.h']]],
   ['uno_5facquiremappingfunc_11',['uno_AcquireMappingFunc',['../a00293.html#abff3fe0eeaae246cfcd6606b1cc492ae',1,'mapping.h']]],
-  ['uno_5fany_12',['uno_Any',['../a00266.html#a61e69c4a6c0e459204403c1d5bb3b2e5',1,'any2.h']]],
-  ['uno_5fany_5fassign_13',['uno_any_assign',['../a00266.html#a887d58dc2f8cec863a30b8b7f17a8b9f',1,'any2.h']]],
-  ['uno_5fany_5fclear_14',['uno_any_clear',['../a00266.html#a7dd15b9945e372e39f02901d5c86aed2',1,'any2.h']]],
-  ['uno_5fany_5fconstruct_15',['uno_any_construct',['../a00266.html#a26ca5ffc96b32c3be3b42ef51436b17f',1,'any2.h']]],
-  ['uno_5fany_5fconstructandconvert_16',['uno_any_constructAndConvert',['../a00266.html#ac2267905a7d95be40499b2aa62bc6b66',1,'any2.h']]],
-  ['uno_5fany_5fdestruct_17',['uno_any_destruct',['../a00266.html#a16e9b54642b986008d3a471d3bb09835',1,'any2.h']]],
+  ['uno_5fany_12',['uno_Any',['../a00263.html#a61e69c4a6c0e459204403c1d5bb3b2e5',1,'any2.h']]],
+  ['uno_5fany_5fassign_13',['uno_any_assign',['../a00263.html#a887d58dc2f8cec863a30b8b7f17a8b9f',1,'any2.h']]],
+  ['uno_5fany_5fclear_14',['uno_any_clear',['../a00263.html#a7dd15b9945e372e39f02901d5c86aed2',1,'any2.h']]],
+  ['uno_5fany_5fconstruct_15',['uno_any_construct',['../a00263.html#a26ca5ffc96b32c3be3b42ef51436b17f',1,'any2.h']]],
+  ['uno_5fany_5fconstructandconvert_16',['uno_any_constructAndConvert',['../a00263.html#ac2267905a7d95be40499b2aa62bc6b66',1,'any2.h']]],
+  ['uno_5fany_5fdestruct_17',['uno_any_destruct',['../a00263.html#a16e9b54642b986008d3a471d3bb09835',1,'any2.h']]],
   ['uno_5fassigndata_18',['uno_assignData',['../a00275.html#ad8a8183a6ebaa70733756297b5d56e89',1,'data.h']]],
   ['uno_5fbindidtocurrentthread_19',['uno_bindIdToCurrentThread',['../a00302.html#adbc1df336622cf2cd74f48fefb25db83',1,'threadpool.h']]],
   ['uno_5fconstructdata_20',['uno_constructData',['../a00275.html#acd377376133394db1928b6dfcd441e09',1,'data.h']]],
@@ -28,16 +28,16 @@ var searchData=
   ['uno_5fdispatchmethod_25',['uno_DispatchMethod',['../a00278.html#aca3081fa5fa64b818fa97c8f0e24edf1',1,'dispatcher.h']]],
   ['uno_5fdumpenvironment_26',['uno_dumpEnvironment',['../a00284.html#ac2292f51663700b6389adbfa4d86ee32',1,'environment.h']]],
   ['uno_5fdumpenvironmentbyname_27',['uno_dumpEnvironmentByName',['../a00284.html#a3f5f15f1c6bcffff60c98638b7ad4321',1,'environment.h']]],
-  ['uno_5fenterable_28',['uno_Enterable',['../a01938.html',1,'']]],
+  ['uno_5fenterable_28',['uno_Enterable',['../a00970.html',1,'']]],
   ['uno_5fenterable_5fcallinto_5fv_29',['uno_Enterable_callInto_v',['../a00260.html#aa72e3a710031e48716221b05637da2d4',1,'Enterable.h']]],
   ['uno_5fenterable_5fcallout_5fv_30',['uno_Enterable_callOut_v',['../a00260.html#a6dc8ae3dfbc0cf9fae077b386d3741c6',1,'Enterable.h']]],
   ['uno_5fenterable_5fenter_31',['uno_Enterable_enter',['../a00260.html#a8a24a898cb8e9b36fc9e450a85bef380',1,'Enterable.h']]],
   ['uno_5fenterable_5fisvalid_5fv_32',['uno_Enterable_isValid_v',['../a00260.html#ab0a2639a88519e99402b5e98bb5dbf3b',1,'Enterable.h']]],
   ['uno_5fenterable_5fleave_33',['uno_Enterable_leave',['../a00260.html#a43424074f509960815ee7e5034b3a959',1,'Enterable.h']]],
   ['uno_5fenvcallee_34',['uno_EnvCallee',['../a00284.html#ab9b865bd93a54c6b944a0c2a7e56563b',1,'environment.h']]],
-  ['uno_5fenvdcp_5fgetpurpose_35',['uno_EnvDcp_getPurpose',['../a00263.html#a9a0dde1b906397e5e6efbecf511e9b92',1,'EnvDcp.h']]],
-  ['uno_5fenvdcp_5fgettypename_36',['uno_EnvDcp_getTypeName',['../a00263.html#a44057a45f74ce74fde1abdc6737f53a7',1,'EnvDcp.h']]],
-  ['uno_5fenvironment_37',['uno_Environment',['../a00284.html#a0057727f6a3e4c9381f41d0d53f6bc20',1,'uno_Environment():&#160;environment.h'],['../a00389.html#a74e26b81b7e694cdfdba825489dcb1cb',1,'uno_Environment():&#160;factory.hxx']]],
+  ['uno_5fenvdcp_5fgetpurpose_35',['uno_EnvDcp_getPurpose',['../a00266.html#a9a0dde1b906397e5e6efbecf511e9b92',1,'EnvDcp.h']]],
+  ['uno_5fenvdcp_5fgettypename_36',['uno_EnvDcp_getTypeName',['../a00266.html#a44057a45f74ce74fde1abdc6737f53a7',1,'EnvDcp.h']]],
+  ['uno_5fenvironment_37',['uno_environment',['../a00392.html#a74e26b81b7e694cdfdba825489dcb1cb',1,'uno_Environment:&#160;factory.hxx'],['../a00284.html#a0057727f6a3e4c9381f41d0d53f6bc20',1,'uno_Environment:&#160;environment.h']]],
   ['uno_5fenvironment_5fenter_38',['uno_Environment_enter',['../a00284.html#a10babae0f34bc1e243fd1ee0861345a8',1,'environment.h']]],
   ['uno_5fenvironment_5finvoke_39',['uno_Environment_invoke',['../a00284.html#a140e3f1812a48adf2a0132cc20dad79f',1,'environment.h']]],
   ['uno_5fenvironment_5finvoke_5fv_40',['uno_Environment_invoke_v',['../a00284.html#a265e36b8a54300e1115e912b9f6e709e',1,'environment.h']]],
@@ -58,17 +58,17 @@ var searchData=
   ['uno_5fgetregisteredenvironments_55',['uno_getRegisteredEnvironments',['../a00284.html#a63698ba5e3bc155159103464fc4fc0e0',1,'environment.h']]],
   ['uno_5finit_5fenvironment_56',['UNO_INIT_ENVIRONMENT',['../a00284.html#a11a567b305a6840caf5e4426bdc8801b',1,'environment.h']]],
   ['uno_5finitenvironmentfunc_57',['uno_initEnvironmentFunc',['../a00284.html#a65fa1b1ce1d750173fdeac329953240f',1,'environment.h']]],
-  ['uno_5finterface_58',['uno_Interface',['../a00278.html#a01e8e71e2517bfaf724992d49a7319d2',1,'uno_Interface():&#160;dispatcher.h'],['../a02521.html#a5d48d6cca53bfac7c4e87cd815059a0e',1,'uno_Interface():&#160;mapping.hxx']]],
+  ['uno_5finterface_58',['uno_interface',['../a00278.html#a01e8e71e2517bfaf724992d49a7319d2',1,'uno_Interface:&#160;dispatcher.h'],['../a02525.html#a5d48d6cca53bfac7c4e87cd815059a0e',1,'uno_Interface:&#160;mapping.hxx']]],
   ['uno_5flb_5fcli_59',['UNO_LB_CLI',['../a00290.html#a84d4660cf5829ea4cafdcc4b0eb959d8',1,'lbnames.h']]],
   ['uno_5flb_5fjava_60',['UNO_LB_JAVA',['../a00290.html#a309a16dcace607fe4cfc5e3a00c8e003',1,'lbnames.h']]],
   ['uno_5flb_5funo_61',['UNO_LB_UNO',['../a00290.html#accb8e197166b7c7ff294fbe084ae3cc8',1,'lbnames.h']]],
   ['uno_5fmapinterfacefunc_62',['uno_MapInterfaceFunc',['../a00293.html#aa7d6cb720868db0b34be2d06e84b52c6',1,'mapping.h']]],
   ['uno_5fmapping_63',['uno_Mapping',['../a00293.html#abe84c421515210d4c58d23656bf77a6e',1,'mapping.h']]],
   ['uno_5fmemalloc_64',['uno_memAlloc',['../a00284.html#a601137e3ecc972111d489346f3d72325',1,'environment.h']]],
-  ['uno_5fquery_65',['UNO_QUERY',['../a00533.html#af9a85aee0004c1028a122e7d48850561a4768d25d9d8bff1a951f8dd49edb4c0f',1,'com::sun::star::uno']]],
-  ['uno_5fquery_5fthrow_66',['UNO_QUERY_THROW',['../a00533.html#a73a6783f81e6afa5cf6b7809662856e9ae6161b6f46e058f8cb2d4ab5216d44e9',1,'com::sun::star::uno']]],
+  ['uno_5fquery_65',['UNO_QUERY',['../a00536.html#af9a85aee0004c1028a122e7d48850561a4768d25d9d8bff1a951f8dd49edb4c0f',1,'com::sun::star::uno']]],
+  ['uno_5fquery_5fthrow_66',['UNO_QUERY_THROW',['../a00536.html#a73a6783f81e6afa5cf6b7809662856e9ae6161b6f46e058f8cb2d4ab5216d44e9',1,'com::sun::star::uno']]],
   ['uno_5fqueryinterfacefunc_67',['uno_QueryInterfaceFunc',['../a00275.html#adf2a74e519b6ea095ff4653b27754a7a',1,'data.h']]],
-  ['uno_5fref_5fno_5facquire_68',['UNO_REF_NO_ACQUIRE',['../a00533.html#a72b3627936fff38db4ee5943cfcb2326a2bf73c7fe836772b039bc9481febf88b',1,'com::sun::star::uno']]],
+  ['uno_5fref_5fno_5facquire_68',['UNO_REF_NO_ACQUIRE',['../a00536.html#a72b3627936fff38db4ee5943cfcb2326a2bf73c7fe836772b039bc9481febf88b',1,'com::sun::star::uno']]],
   ['uno_5fregistermapping_69',['uno_registerMapping',['../a00293.html#acc11a313476188775a94dd3bc7d161e4',1,'mapping.h']]],
   ['uno_5fregistermappingcallback_70',['uno_registerMappingCallback',['../a00293.html#af52ed9cbaf0f1e11c62e7c3c21873bd1',1,'mapping.h']]],
   ['uno_5freleasefunc_71',['uno_ReleaseFunc',['../a00275.html#a55022adf86896f1a0ff9f78eb14afc22',1,'data.h']]],
@@ -81,7 +81,7 @@ var searchData=
   ['uno_5fsequence_5fconstruct_78',['uno_sequence_construct',['../a00299.html#a5c4fd52721a784b96ed948b349e7bd5f',1,'sequence2.h']]],
   ['uno_5fsequence_5frealloc_79',['uno_sequence_realloc',['../a00299.html#ae0e608ca7ea91de00d8547efb282d3bb',1,'sequence2.h']]],
   ['uno_5fsequence_5freference2one_80',['uno_sequence_reference2One',['../a00299.html#a83cb791c46cb2cfaa6b782e88a958bf1',1,'sequence2.h']]],
-  ['uno_5fset_5fthrow_81',['UNO_SET_THROW',['../a00533.html#afd8938f38e6e9bea9e6ad5eb058ccd26abfdc414638f4f6217e24761c277c09cb',1,'com::sun::star::uno']]],
+  ['uno_5fset_5fthrow_81',['UNO_SET_THROW',['../a00536.html#afd8938f38e6e9bea9e6ad5eb058ccd26abfdc414638f4f6217e24761c277c09cb',1,'com::sun::star::uno']]],
   ['uno_5fsetcurrentcontext_82',['uno_setCurrentContext',['../a00269.html#ac276c78baec7ac89ed38ba87241fdbf4',1,'current_context.h']]],
   ['uno_5fthreadpool_83',['uno_ThreadPool',['../a00302.html#a652117a32126083087ed23fb7c76439d',1,'threadpool.h']]],
   ['uno_5fthreadpool_5fattach_84',['uno_threadpool_attach',['../a00302.html#afa3c95f71a98d0ed52eb5543c3591ba8',1,'threadpool.h']]],
@@ -91,9 +91,9 @@ var searchData=
   ['uno_5fthreadpool_5fdispose_88',['uno_threadpool_dispose',['../a00302.html#a1c9ef78813d995e00c45a3f82f4c4d63',1,'threadpool.h']]],
   ['uno_5fthreadpool_5fenter_89',['uno_threadpool_enter',['../a00302.html#a34085bbf8d4fa08146251a343934cffa',1,'threadpool.h']]],
   ['uno_5fthreadpool_5fputjob_90',['uno_threadpool_putJob',['../a00302.html#aadd8fabb40ab461018b5c95f7b10f3c9',1,'threadpool.h']]],
-  ['uno_5ftype_5fany_5fassign_91',['uno_type_any_assign',['../a00266.html#a67b1de05d331ff86922e7e9099a65339',1,'any2.h']]],
-  ['uno_5ftype_5fany_5fconstruct_92',['uno_type_any_construct',['../a00266.html#a567d2f5ec2ab847b5d16a1818844c2a4',1,'any2.h']]],
-  ['uno_5ftype_5fany_5fconstructandconvert_93',['uno_type_any_constructAndConvert',['../a00266.html#af821b36fd4207ff296c92898b3bbe7cd',1,'any2.h']]],
+  ['uno_5ftype_5fany_5fassign_91',['uno_type_any_assign',['../a00263.html#a67b1de05d331ff86922e7e9099a65339',1,'any2.h']]],
+  ['uno_5ftype_5fany_5fconstruct_92',['uno_type_any_construct',['../a00263.html#a567d2f5ec2ab847b5d16a1818844c2a4',1,'any2.h']]],
+  ['uno_5ftype_5fany_5fconstructandconvert_93',['uno_type_any_constructAndConvert',['../a00263.html#af821b36fd4207ff296c92898b3bbe7cd',1,'any2.h']]],
   ['uno_5ftype_5fassigndata_94',['uno_type_assignData',['../a00275.html#aad5b81bcdbf58cc81e83aff0abf5bfa8',1,'data.h']]],
   ['uno_5ftype_5fconstructdata_95',['uno_type_constructData',['../a00275.html#a1a522b6b2affee2ed6f5b8ea2160fc1d',1,'data.h']]],
   ['uno_5ftype_5fcopyandconvertdata_96',['uno_type_copyAndConvertData',['../a00275.html#a853a7bf7c96feddb6a9915b223672702',1,'data.h']]],
@@ -101,41 +101,41 @@ var searchData=
   ['uno_5ftype_5fdestructdata_98',['uno_type_destructData',['../a00275.html#a43fc2bbd97c9ca86c83b24a975b64ba8',1,'data.h']]],
   ['uno_5ftype_5fequaldata_99',['uno_type_equalData',['../a00275.html#a8530d0232005bd9d3e8f6cd2f5c8138b',1,'data.h']]],
   ['uno_5ftype_5fisassignablefromdata_100',['uno_type_isAssignableFromData',['../a00275.html#a7b64f12a8b1dbe71534d114bcc9fb252',1,'data.h']]],
-  ['uno_5ftype_5fno_5facquire_101',['UNO_TYPE_NO_ACQUIRE',['../a00533.html#a72b6c10d5cb770d942e2156c1b3160f9a00c7c79af29c4f7755c90cfee9d9271d',1,'com::sun::star::uno']]],
+  ['uno_5ftype_5fno_5facquire_101',['UNO_TYPE_NO_ACQUIRE',['../a00536.html#a72b6c10d5cb770d942e2156c1b3160f9a00c7c79af29c4f7755c90cfee9d9271d',1,'com::sun::star::uno']]],
   ['uno_5ftype_5fsequence_5fassign_102',['uno_type_sequence_assign',['../a00299.html#afea487fb22d675aaefee133f0ee45527',1,'sequence2.h']]],
   ['uno_5ftype_5fsequence_5fconstruct_103',['uno_type_sequence_construct',['../a00299.html#add905a8925a79cb54cbda991af711f9f',1,'sequence2.h']]],
   ['uno_5ftype_5fsequence_5fdestroy_104',['uno_type_sequence_destroy',['../a00299.html#a8b0bc4cc6acfac970f79fe2f8352f564',1,'sequence2.h']]],
   ['uno_5ftype_5fsequence_5frealloc_105',['uno_type_sequence_realloc',['../a00299.html#a1448f50fc11735e422fe9ffe11b880ec',1,'sequence2.h']]],
   ['uno_5ftype_5fsequence_5freference2one_106',['uno_type_sequence_reference2One',['../a00299.html#a707ab70bf1b37f59d36f7afe642982b3',1,'sequence2.h']]],
-  ['unoreference_5fnoacquire_107',['UnoReference_NoAcquire',['../a00533.html#a72b3627936fff38db4ee5943cfcb2326',1,'com::sun::star::uno']]],
-  ['unoreference_5fquery_108',['UnoReference_Query',['../a00533.html#af9a85aee0004c1028a122e7d48850561',1,'com::sun::star::uno']]],
-  ['unoreference_5fquerythrow_109',['UnoReference_QueryThrow',['../a00533.html#a73a6783f81e6afa5cf6b7809662856e9',1,'com::sun::star::uno']]],
-  ['unoreference_5fsetthrow_110',['UnoReference_SetThrow',['../a00533.html#afd8938f38e6e9bea9e6ad5eb058ccd26',1,'com::sun::star::uno']]],
-  ['unosequencetype_111',['UnoSequenceType',['../a00574.html',1,'cppu']]],
-  ['unotype_112',['UnoType',['../a00570.html',1,'cppu']]],
+  ['unoreference_5fnoacquire_107',['UnoReference_NoAcquire',['../a00536.html#a72b3627936fff38db4ee5943cfcb2326',1,'com::sun::star::uno']]],
+  ['unoreference_5fquery_108',['UnoReference_Query',['../a00536.html#af9a85aee0004c1028a122e7d48850561',1,'com::sun::star::uno']]],
+  ['unoreference_5fquerythrow_109',['UnoReference_QueryThrow',['../a00536.html#a73a6783f81e6afa5cf6b7809662856e9',1,'com::sun::star::uno']]],
+  ['unoreference_5fsetthrow_110',['UnoReference_SetThrow',['../a00536.html#afd8938f38e6e9bea9e6ad5eb058ccd26',1,'com::sun::star::uno']]],
+  ['unosequencetype_111',['UnoSequenceType',['../a01018.html',1,'cppu']]],
+  ['unotype_112',['UnoType',['../a01014.html',1,'cppu']]],
   ['unotype_2ehxx_113',['unotype.hxx',['../a00329.html',1,'']]],
-  ['unotype_5fnoacquire_114',['UnoType_NoAcquire',['../a00533.html#a72b6c10d5cb770d942e2156c1b3160f9',1,'com::sun::star::uno']]],
-  ['unourl_115',['UnoUrl',['../a01498.html',1,'cppu::UnoUrl'],['../a01498.html#a23b5e876eecd29a9f1e5161b1e3a8407',1,'cppu::UnoUrl::UnoUrl(UnoUrl const &amp;rOther)'],['../a01498.html#af74f9f63ba57a8664ce63da416fa7b83',1,'cppu::UnoUrl::UnoUrl(rtl::OUString const &amp;rUrl)']]],
+  ['unotype_5fnoacquire_114',['UnoType_NoAcquire',['../a00536.html#a72b6c10d5cb770d942e2156c1b3160f9',1,'com::sun::star::uno']]],
+  ['unourl_115',['unourl',['../a01942.html#a23b5e876eecd29a9f1e5161b1e3a8407',1,'cppu::UnoUrl::UnoUrl()'],['../a01942.html',1,'cppu::UnoUrl'],['../a01942.html#af74f9f63ba57a8664ce63da416fa7b83',1,'cppu::UnoUrl::UnoUrl()']]],
   ['unourl_2ehxx_116',['unourl.hxx',['../a00476.html',1,'']]],
-  ['unourldescriptor_117',['UnoUrlDescriptor',['../a01494.html',1,'cppu::UnoUrlDescriptor'],['../a01494.html#a35adf9b2722dcfe5dd0cf0a0588e2ac2',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(rtl::OUString const &amp;rDescriptor)'],['../a01494.html#adc91019dd09706a1e8a083244967f78d',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(UnoUrlDescriptor const &amp;rOther)']]],
-  ['unusedsince_118',['unusedSince',['../a01782.html#a2c27af5fa12d01c9c39f80eb0b2c36c3',1,'_rtl_StandardModuleCount']]],
-  ['uri_119',['Uri',['../a01786.html',1,'rtl']]],
+  ['unourldescriptor_117',['unourldescriptor',['../a01938.html',1,'cppu::UnoUrlDescriptor'],['../a01938.html#a35adf9b2722dcfe5dd0cf0a0588e2ac2',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(rtl::OUString const &amp;rDescriptor)'],['../a01938.html#adc91019dd09706a1e8a083244967f78d',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(UnoUrlDescriptor const &amp;rOther)']]],
+  ['unusedsince_118',['unusedSince',['../a00742.html#a2c27af5fa12d01c9c39f80eb0b2c36c3',1,'_rtl_StandardModuleCount']]],
+  ['uri_119',['Uri',['../a00746.html',1,'rtl']]],
   ['uri_2eh_120',['uri.h',['../a00143.html',1,'']]],
   ['uri_2ehxx_121',['uri.hxx',['../a00146.html',1,'']]],
-  ['userdata_122',['UserData',['../a01606.html#a94fb723f758d991a10e73d7bf1f5b5f0',1,'oslSignalInfo']]],
-  ['usersignal_123',['UserSignal',['../a01606.html#ab9106b39d2c7ae15f39aeee2b287241a',1,'oslSignalInfo']]],
-  ['usertime_124',['UserTime',['../a01594.html#acdbec544965f2ff1f1085b11bfa2f9e3',1,'oslProcessInfo']]],
+  ['userdata_122',['UserData',['../a00850.html#a94fb723f758d991a10e73d7bf1f5b5f0',1,'oslSignalInfo']]],
+  ['usersignal_123',['UserSignal',['../a00850.html#ab9106b39d2c7ae15f39aeee2b287241a',1,'oslSignalInfo']]],
+  ['usertime_124',['UserTime',['../a00838.html#acdbec544965f2ff1f1085b11bfa2f9e3',1,'oslProcessInfo']]],
   ['ustrbuf_2eh_125',['ustrbuf.h',['../a00149.html',1,'']]],
   ['ustrbuf_2ehxx_126',['ustrbuf.hxx',['../a00152.html',1,'']]],
-  ['ustrfilename_127',['ustrFileName',['../a01522.html#a52fc198fb3cd85d3b41ef5cf1efe5215',1,'_oslFileStatus']]],
-  ['ustrfilesystemname_128',['ustrFileSystemName',['../a01526.html#a9455d8abee0819e384a537c306d88a7f',1,'_oslVolumeInfo']]],
-  ['ustrfileurl_129',['ustrFileURL',['../a01522.html#ac225b4dc066bcc99088e3a8f9614ab2a',1,'_oslFileStatus']]],
+  ['ustrfilename_127',['ustrFileName',['../a00766.html#a52fc198fb3cd85d3b41ef5cf1efe5215',1,'_oslFileStatus']]],
+  ['ustrfilesystemname_128',['ustrFileSystemName',['../a00770.html#a9455d8abee0819e384a537c306d88a7f',1,'_oslVolumeInfo']]],
+  ['ustrfileurl_129',['ustrFileURL',['../a00766.html#ac225b4dc066bcc99088e3a8f9614ab2a',1,'_oslFileStatus']]],
   ['ustring_2eh_130',['ustring.h',['../a00155.html',1,'']]],
   ['ustring_2ehxx_131',['ustring.hxx',['../a00158.html',1,'']]],
-  ['ustrlinktargeturl_132',['ustrLinkTargetURL',['../a01522.html#a2de4bbf56cecf5435fe11dea696092ce',1,'_oslFileStatus']]],
-  ['ustructsize_133',['uStructSize',['../a01526.html#ae7df80711543ea419945503a03d227fe',1,'_oslVolumeInfo::uStructSize()'],['../a01522.html#a9dd21f3d1a624da3b85b65caba4282ac',1,'_oslFileStatus::uStructSize()']]],
-  ['utotalspace_134',['uTotalSpace',['../a01526.html#a82cd611883c8c6187e4cc090e37b5137',1,'_oslVolumeInfo']]],
+  ['ustrlinktargeturl_132',['ustrLinkTargetURL',['../a00766.html#a2de4bbf56cecf5435fe11dea696092ce',1,'_oslFileStatus']]],
+  ['ustructsize_133',['ustructsize',['../a00770.html#ae7df80711543ea419945503a03d227fe',1,'_oslVolumeInfo::uStructSize'],['../a00766.html#a9dd21f3d1a624da3b85b65caba4282ac',1,'_oslFileStatus::uStructSize']]],
+  ['utotalspace_134',['uTotalSpace',['../a00770.html#a82cd611883c8c6187e4cc090e37b5137',1,'_oslVolumeInfo']]],
   ['uuid_2eh_135',['uuid.h',['../a00161.html',1,'']]],
-  ['uusedspace_136',['uUsedSpace',['../a01526.html#a4dcd71fa9f7fd7f2c9924651b1f9d1e1',1,'_oslVolumeInfo']]],
-  ['uvalidfields_137',['uValidFields',['../a01526.html#a177b8213c8e157fe61ded493f8d40e87',1,'_oslVolumeInfo::uValidFields()'],['../a01522.html#a1ea0b2e33b86e8cb9680c16c9f0611da',1,'_oslFileStatus::uValidFields()']]]
+  ['uusedspace_136',['uUsedSpace',['../a00770.html#a4dcd71fa9f7fd7f2c9924651b1f9d1e1',1,'_oslVolumeInfo']]],
+  ['uvalidfields_137',['uvalidfields',['../a00770.html#a177b8213c8e157fe61ded493f8d40e87',1,'_oslVolumeInfo::uValidFields'],['../a00766.html#a1ea0b2e33b86e8cb9680c16c9f0611da',1,'_oslFileStatus::uValidFields']]]
 ];
